@@ -24,7 +24,7 @@ function(x, w0=0.2, p0=0.2, burnin=50, mcmc=500, return.mcmc=FALSE) {
 	out <- .C("Cbcp", 
 		PACKAGE="bcp", 
 		data = as.double(x), 
-		mcmcreturn = as.double(mcmcreturn),
+		mcmcreturn = as.integer(mcmcreturn),
 		n = as.integer(n), 
 		burnin = as.integer(burnin), 
 		mcmc = as.integer(mcmc),     
@@ -50,8 +50,8 @@ function(x, w0=0.2, p0=0.2, burnin=50, mcmc=500, return.mcmc=FALSE) {
 			results[m,] <- out$results[start[m]:end[m]]
 		}
 	} else {
-		rhos <- "NA"
-		results <- "NA"
+		rhos <- NA
+		results <- NA
 	}
 	
 	# RETURN RESULTS
